# Make _your_ edition: models and methods for digital textual scholarship

## Call for applications: Summer 2017 NEH Institute for Advanced Topics in the Digital Humanities

**Deadlines:** Applications are due Tuesday, February 28, 2017. Applicants will be notified of acceptance by March 15, 2017. 

**Institute dates:** July 10-29, 2017

## Synopsis

The University of Pittsburgh is pleased to invite applications to an NEH Advanced Institute in the Digital Humanities for summer 2017 entitled _Make **your** edition: models and methods of digital textual scholarship_. The target audience for this workshop is digital textual scholars who are already comfortable editing their texts (in TEI XML or comparable alternatives); the goal of the Institute is to assist them in moving beyond textual editing to imagining, creating, and publishing research-driven, theoretically and methodologically innovative digital editions.

## Rationale

Digital humanists already have access to workshops and tutorials to help them learn to transcribe, edit, and tag a text in preparation for publishing a digital edition. These training resources play a vital role in empowering editors to formalize and instantiate their interpretations as markup, so as to make them available for subsequent analysis. Nonetheless, sophisticated markup expertise alone is not enough to make an edition, and learning nothing more than tagging may leave scholars staring at their angle brackets and wondering what to do next. For some a solution like TEI Tapas provides an adequate next step, but for those who wish to ask new types of questions of their documents, and to produce new types of editions that enable new types of research, an understanding of how to turn a set of tagged texts into a customized edition that meets individualized research goals is crucial. Digital humanists cannot build editions that break new methodological ground solely on the basis of solutions prepared largely by others, and the focus of this Institute is on the creation of digital editions motivated by project-specific research questions and implemented from a perspective driven first by theory of edition, second by editorial methodology, and necessarily but less importantly by specific toolkits. In this respect we foreground not learning a particular programming language or technology or framework, but learning to think and act digitally about the process of creating a digital edition. Because tools and technologies come and go, the Institute emphasizes learning to translate original digital thinking about editions into implementations of those editions, rather than on “tooling up” in the context of currently popular frameworks. In this respect, the Institute recognizes thinking digitally in ways driven by project-specific research goals as the most important feature of _sustainable Digital Humanities training and education_.

## Program

The Institute will introduce textual and manuscript scholars to a powerful and broad-reaching skill set of digital methods and technologies, grounded in a context that prioritizes a research-driven theory of edition. The course moves in a three-week succession from novice to experienced level, and from base textual data to full digital publication of scholarly editions. The Institute assumes that participants will have meaningful prior experience in digital editing (in TEI XML or a comparable framework), but it makes no other assumptions about prior knowledge or skills.

* An optional first-week _boot camp_ establishes basic infrastructure skills (operating comfortably at the command line, handling files, navigating file systems, sharing resources and code responsibly, running Python programs from the command line, etc.).
* The second week allows participants to practice and advance their basic skills when they start combining digital textual scholarship theory (e.g., McGann 2004<sup>1</sup>, Andrews 2012<sup>2</sup>, Siemens 2012<sup>3</sup>, Robinson 2013<sup>4</sup>, Haentjens et al. 2015<sup>5</sup>) with standard (e.g., XML, Python, Jupyter Notebooks) and advanced digital technologies (e.g., StemmaWeb, CollateX, Neo4j, Tinkerpop, eXist-db).
* By the end of the third week, participants will be able to conceptualize from theory a perspective on digital textual scholarship and digital scholarly editions. They will also know how to go about planning and implementing such an edition by engaging programmatically and algorithmically with digital data, handling it computationally, and querying, analyzing, and transforming it into visualizations that transcend the digital translation of a text as a codex.

The Institute will meet at the main (Oakland) campus of the University of Pittsburgh from Monday, July 10, 2017 through Friday, July 28, 2017 and will draw on an international faculty of distinguished scholars, practitioners, and teachers of digital philology from several collaborating institutions. On Saturday, July 29, 2017 there will be an optional pedagogical review of the Institute, designed to assist participants in organizing and conducting their own workshops at their home institutions.

## Instructors
* Tara Andrews (Institute of History, University of Vienna)
* David J. Birnbaum (Department of Slavic Languages and Literatures, University of Pittsburgh)
* Hugh Cayless (Duke Collaboratory for Classics Computing [DC3], Duke University)
* Ronald Haentjens Dekker (Huygens Institute, Royal Netherlands Academy of Arts and Sciences)
* Na-Rae Han (Department of Linguistics, University of Pittsburgh)
* Mike Kestemont (Department of Literature, University of Antwerp)
* Leif-Jöran Olsson (Department of Swedish Language, University of Gothenburg)

The instructors will be assisted by:

* Gabrielle (Gabi) Keane (Senior Undergraduate Institute Assistant, University of Pittsburgh)
* Kaylen Sanders (Junior Undergraduate Institute Assistant, University of Pittsburgh)


## Details

Applications are invited for the full three-week Institute or, in the case of those who are already comfortable with the types of first-week topics described above, for just the second and third weeks. Applicants should already be proficient with digital textual editing in TEI XML or similar technologies, and should be seeking guidance and training in how to move their texts into innovative digital editions that will enable them to explore project-specific research questions. Evidence of meaningful prior hands-on digital textual editing experience is required, but prior experience in programming for textual exploration and publication is not. Applicants who do not have prior experience with the Python programming language must agree to complete a recommended free online introductory Python course before the beginning of the Institute, for which the Institute will maintain its own support and discussion board. For budgetary reasons, preference will be given to applications from within North America.

Participants accepted to the Institute will receive a travel allowance, complimentary accommodation in single-occupancy dormitory rooms, and a complimentary meal plan in the University Dining Services in lieu of per diem. Access to the University libraries, computer labs, and networked digital resources will also be provided. Participants must bring their own laptops (Windows 7–10, Mac OS, or Ubuntu/Debian Linux). We welcome scholars at all career levels from advanced graduate students through senior faculty. Applications to the Institute should include the following:

* A one- to two-page statement about how participation in the Institute will enhance the scholarly and professional goals of the applicant. This statement should describe the digital edition project that the applicant plans to pursue or undertake, with special attention to the research questions motivating the creation of that edition. Preference will be shown to applications that articulate a clear understanding of the textual research potential of digital scholarly editions.
* A one-page description of the applicant’s experience with textual editing. Prior experience in programming for text processing is neither required nor expected, but those who have such experience should describe it here.
* Brief CV (maximum of two pages), concentrating on textual editing and Digital Humanities experience.
* Indicate whether you are applying for the full three weeks or only for the second and third, and in the latter case please describe your background in the areas related to those described above as part of the “boot camp” week.
* Indicate whether you wish to participate in the optional one-day pedagogical review of the course on Saturday, July 29.
* Participants are required to participate full-time in the Institute for the two or three weeks that they are in residence, and must confirm that they will not undertake other significant commitments during the Institute period.

All application materials should be submitted by email as a single PDF file to djbpitt+neh@pitt.edu. The deadline for applications is Tuesday, February 28, 2017, and applicants will be notified by March 15, 2017. Questions may be directed to djbpitt+neh@pitt.edu.

David J. Birnbaum, Institute Director  
Professor and Chair, Slavic Languages and Literatures  
Faculty Fellow, University Honors College  
Email: djbpitt+neh@pitt.edu
_____
## References

1. McGann, Jerome, 2004. “Marking texts of many dimensions.” In Susan Schreibman, Raymond Siemens, and John Unsworth, eds. _A companion to Digital Humanities_. Oxford: Blackwell.
1. Andrews, Tara L., 2012. “The third way: philology and critical edition in the digital age.” _Variants_ 10, pp. 61–76.
1. Siemens, Raymond et al., 2012. “Toward modeling the social edition: An approach to understanding the electronic scholarly edition in the context of new and emerging social media.” _Literary and linguistic computing_, 27(4), pp. 445–61.
1. Robinson, Peter, 2012. “Towards a theory of digital editions.” _Variants_ 10, pp.105–31.
1. Haentjens Dekker, Ronald, Dirk van Hulle, Gregor Middell, Vincent Neyt, Joris van Zundert, 2015. “Computer-supported collation of modern manuscripts: CollateX and the Beckett Digital Manuscript Project”, _Digital scholarship in the humanities_, 30(3), pp. 452–70.

___
This announcement has been posted to Humanist (<http://dhhumanist.org/>), Digital Classicist (<http://www.digitalclassicist.org/>), Digital Medievalist (<https://digitalmedievalist.wordpress.com/>), TEI-L (<http://www.tei-c.org/Support/index.xml#tei-l>), WWP-Encoding (<http://listserv.neu.edu/cgi-bin/wa?A0=wwp-encoding>), and DHUF Digital Humanities Flanders (<dh_flanders@googlegroups.com>). Please circulate.