# Exemplary editions

The following editions were chosen not only because of their quality, but also because they illustrate unusual methods that transcend, in different ways, the features commonly found in digital editions.

* **Digital Thoreau** (<https://digitalthoreau.org/>) brings together scholarship on American author Henry David Thoreau. An edition of his work _Walden_ is [available](<https://digitalthoreau.org/fluid-text-toc/>) as fluid text, visualized by the Versioning Machine including in-text deletions, additions and scholarly annotations. 
* **Faust edition** (<http://beta.faustedition.net/>). This edition uses range-based text repository software combined with a graph database. The material is transcribed using multiple XML files per unit, where each XML file contains a separate hierarchy: one focusing on the document hierarchy and one focusing on the text hierarchy. Within the text repository the different hierarchies are combined in a multi-layered view of the text. Source: <https://github.com/faustedition/faust-app/tree/master/faust/src/main/java/de/faustedition/graph>
* **Münster New Testament project** by the INTF (<http://egora.uni-muenster.de/intf/projekte/projekte_en.shtml>) poses special challenges to automated collation because of the unusually large number of witnesses involved in textual criticism of the New Testament. 
* **The Old Bailey Online** (<https://www.oldbaileyonline.org/index.jsp>) is a digitized collection of nearly 2000,000 transcribed trial records of the men and women convicted in London (UK) between 1676 and 1772. The overall project has a pedagogical orientation as it offers multiple tutorials, research guides, and teaching material. There's an impressive [range](https://www.oldbaileyonline.org/static/Projects.jsp) of digital projects that have made succesfull use of the Old Bailey data (available as TEI-XML or API), e.g., a linguistic corpus of spoken English from 1720 to 1913. 
* **Petrus Plaoul** (<http://petrusplaoul.org>). TEI XML transcription of Peter Plaoul’s Commentary on the Sentences of Peter Lombard. The transcribed pages (e.g., <http://petrusplaoul.org/text/textdisplay.php?fs=lectio1>) provide mouse-over and menu interfaces.
* **Samuel Beckett project** (<http://www.beckettarchive.org/>) contains TEI XML editions of Samuel Beckett’s manuscripts. It uses Apache Cocoon, a publishing framework build on XML technologies, and extends the digital edition paradigm by modeling genetic editions that capture the incremental process by which the manuscripts evolved.
* **Shebanq project** (<https://shebanq.ancient-data.org/>). This edition of the Hebrew Bible, which won a prize from CLARIN-NL, uses a custom made text database (using a graph-like structure) and text query language (MQL). Documentation: <https://shebanq.ancientdata.org/shebanq/static/docs/featuredoc/texts/welcome.html>
* **Shelley Godwin Archive** (<http://shelleygodwinarchive.org/>) makes available TEI-encoded genetic editions of the manuscripts of Percy Bysshe Shelley, Mary Wollstonecraft Shelley, William Godwin, and Mary Wollstonecraft. The reading interface provides unusual and illuminating control of the visualization of how different persons contributed text and annotations to the eventual manuscript page.
* **St. Patrick’s Confession** (<http://www.confessio.ie/about/hyperstack>) goes a long way toward providing an integrated perspective on scholarly editing and digital technology/methodology.
* **Thomas Gray Archive** (<http://www.thomasgray.org/cgi-bin/display.cgi?text=elcc#panel_ana>). The metrical and other structures underlying poetic texts constitute an annotation layer that may be difficult to integrate into a textual publication. This edition is enriched with a computationally facilitated analysis of the text, with richer commentary exposed in the notes and queries.
* **Van Gogh Letters** (<http://vangoghletters.org/vg/>) offer a subtle but powerful navigational platform for exploring Van Gogh’s correspondence, and can serve as an example of how developer perspectives and user affordances can be combined to support user-directed exploration.
* **Vercelli Book Project** (<http://vbd.humnet.unipi.it/>) uses the Edition Visualization Technology (EVT) framework (<http://evt.labcd.unipi.it/>) to render a multi-dimensional interface that supports seamless navigation and comparison of scans of the original manuscript, transcribed text, and adapted transcription.
* **Welscher Gast digital project** (<http://digi.ub.uni-heidelberg.de/wgd/>) is impressive for its linking of text to iconography in illustrations.

See also “A catalogue of digital editions” (Franzini, Terras, and Mahony, 2012) at <https://github.com/gfranzini/digEds_cat>.