# Institute materials, organized by topic

Materials are organized by relevance to beginners (those just planning a project) to advanced edition makers (those ready to release an edition). Links include original materials and outside sources.


## Project planning
* [Project planning guide](../schedule/week_2/project_planning.md)
* [Computational pipelines](../../schedule/week_2/computational_pipeline.md)

## Git
* [Git resources page](../schedule/week_1/git_resources.md)
* [Git 1](../schedule/week_1/git_1.md)
* [Git 2](../schedule/week_1/git_2.md)
* [Forking the Institute repo](../schedule/week_2/fork.md)
* [Publishing on GitHub Pages](https://guides.github.com/features/pages/)

## Operating system
* [Getting to know Windows](../schedule/week_1/getting_to_know_windows.md)
* [Getting to know Mac](../schedule/week_1/getting_to_know_mac.md)

## Documentation
* [`man`](https://www.cs.mcgill.ca/~guide/help/man.html)
* [SS64 command line reference](https://ss64.com)

## Errors
* [Don't panic](../schedule/week_1/dont_panic.md)

## Commands, programs, files
* [Programs and files 1](../schedule/week_1/programs_1.md)
* [Programs and files 2](../schedule/week_1/programs_2.md)
* [Windows command line](../schedule/week_1/command_1_windows.md)
* [Mac command line](../schedule/week_1/command_1_mac.md)
* [Command line 2](../schedule/week_1/command_2.md)
* [Command line 3](../schedule/week_1/command_3.md)

## Regex
* [Regex 1](../schedule/week_1/regex_1.md)
* [Regex 2](../schedule/week_1/regex_2.md)
* [Regex resources](../schedule/week_1/regex_resources.md)
* [Regex builder](https://regex101.com)
* [Command 3 (`grep`)](https://pittsburgh-neh-institute.github.io/Institute-Materials-2017/schedule/week_1/command_3.html#finding-things-with-grep)

## Internet (HTTP)
* [How the Internet works 1](../schedule/week_1/internet_1.md)
* [How the Internet works 2](../schedule/week_1/internet_2.md)

## Web (HTML, CSS, JavaScript)
* [Web technologies](../schedule/week_1/web_technologies.md)
* [MDN HTML](https://developer.mozilla.org/en-US/docs/Web/HTML)
* [MDN CSS](https://developer.mozilla.org/en-US/docs/Web/CSS)
* [MDN JavaScript](https://developer.mozilla.org/en-US/docs/Web/JavaScript)

## Queries and XML
* [XPath](../schedule/week_2/xpath.md)
* [XQuery 1](../schedule/week_2/xquery_1.md)
* [XQuery 2](../schedule/week_3/xquery_2.md)
* [XQuery webapps tutorial](../schedule/week_3/xquery_3.md)

## Python
* [Anaconda Python](https://www.anaconda.com/download/)
* [PyCharm](https://www.jetbrains.com/pycharm/)
* [Python 1](../schedule/week_1/python_1.html)
* [Python 2](../schedule/week_1/python_2.html)
* Note: Git `bash` requires the use of `winpty` when running certain Windows applications that are meant to run within `cmd`. For example, to run an interactive python session, you should execute `winpty python`. You may want to alias Python by adding`alias python='winpty python.exe'` to your `.bashrc` file.

## Model, syntax, and markup semantics
* [Model, syntax, and markup semantics](../schedule/week_2/model_syntax_semantics.md)
* [Plain text as model and expression](../schedule/week_2/plain.md)
* [XML as model and expression](../schedule/week_2/xml_model.md)
* [Other models and expressions: LMNL, GODDAG, TexMECS, TAG](../schedule/week_2/other_models.md)

### XML
* [XML as tree](../schedule/week_2/xpath.md)
* [Overlap in XML](../schedule/week_2/overlap_xml.md)
* [Markup](../schedule/week_2/explicit.md)
* [What’s hard in XML?](../schedule/week_2/xml_limitations.md)
* [XML and OHCO](../schedule/week_2/ohco.md)

### LMNL
* [LMNL](../schedule/week_2/lmnl_syntax.md)
* [LMNL and Alexandria](../schedule/week_2/lmnl_alexandria.md)

### TAG
* [What is TAG?](../schedule/week_2/tag.md)
* [Install Docker](https://docs.docker.com/install/#platform-support-matrix)
	* Note: If you are running Windows 10 Home edition (or any OS older than Windows 10), you will install [Docker Toolbox](https://docs.docker.com/toolbox/overview/) instead. Windows 10 HE does not support the Hyper-V Windows feature required to run a full installation of Docker.
* [Running Alexandria](../schedule/week_3/alexandria.md)

## Visualization
* [What story are you trying to tell?](../schedule/week_2/sample_visualizations.md)
* [Text visualization](../schedule/week_3/visualization.md)

## Theory of edition
* [Edition terms and concepts](../schedule/week_2/edition_terms_and_concepts.md)
* [What is a digital workstation?](../schedule/week_3/digital_workstation.md)

## The Gothenburg model of textual collation
* [CollateX installation](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/collatex_installation.ipynb)
* [Gothenburg model](../schedule/week_2/gothenburg.md)
	1. [Tokenization](../schedule/week_2/tokenization.md)
		* [Tokenization notebook](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/Tokenization.ipynb)
	1. Normalization
		* [Normalization notebook](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/Normalization.ipynb)
		* [Normalization examples](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/Normalization_examples.ipynb)
		* [Unicode normalization](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/Unicode_normalization.ipynb)
		* [Soundex normalization](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/Soundex_normalization.ipynb)
		* [Integrating tokenization and normalization](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/Integrating_tokenization_and_normalization.ipynb)
	1. [Alignment](../schedule/week_2/alignment.md)
	1. [Analysis](../schedule/week_2/analysis.md)
		* [Near matching](https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/schedule/week_2/Near_matching.ipynb)
	1. Visualization (serialization)

## Text analytics (Mike)
* [Mike Kestemont's website](http://www.mike-kestemont.org/)

## Web publishing frameworks
* [CETEIcean](http://philomousos.com/CETEIcean/index.html)
* [GitHub pages](https://pages.github.com/)
* [Flask](http://flask.pocoo.org/)
* eXist-db
	* [eXist-db install](http://exist-db.org/exist/apps/homepage/index.html)
	* [eXist-db, XQuery, and webapps ](https://pittsburgh-neh-institute.github.io/Institute-Materials-2017/schedule/week_3/exist_xquery_webapps.html)

## LOD / RDF / SPARQL
* [RDF and SPARQL](../schedule/week_3/rdf_sparql.md)
* [Linked Open Data (LOD)](../schedule/week_2/lod.md)

## TEI stylesheets
* [TEI Stylesheets GitHub](https://github.com/TEIC/Stylesheets#stylesheets)
* [Using Docker to run Stylesheets](../schedule/week_3/xslt.md)

## APIs
* [Intro to Application Programming Interfaces](../schedule/week_3/api_intro.md)
* [Using an API in your edition](../schedule/week_3/using_apis_edition.md)
* [Build your API](../schedule/week_3/building_apis.md)


## [Publishing strategies](../schedule/week_3/publish.md)
* [Creative Commons Licensing](https://creativecommons.org/)
* Archiving
* Sustainability

## Example projects
* [List of participant editions/testimony](participant_editions.md)
* [List of exemplary editions](exemplary_editions.md)