# The _digital workstation_

## What is a _digital edition_?

The critical edition is an important part of many scholarly projects, but the contents and layout of traditional critical editions are constrained by the physical limitations of paper publication. While digital publication also comes with limitations, a digital edition has the potential to include more information, more types of information, and more views of the same information than a print book could. Crucially, paper publication has a single dominant organization, the order of the the pages, and other modes of navigation (e.g., table of contents, back-of-the-book index, list of figures) are subordinate to page order, by which we mean that they end in pointers to specific pages. Digital editions, which can range from the simple HTML interface of a Project Gutenberg book to the advanced lightbox feature of the Blake Archive, can be designed to support multiple perspectives on multiple research questions, which gives them the potential of being more accessible and more useful to a wider scholarly community.  

## What is a _digital workstation_?

### Overview

Not every digital edition takes full advantage of the capabilities of digital publication, and some do little more than transfer the organization of a paper edition to the screen. The digital workstation goes beyond simpler digital editions by regarding the interface as a first-class component of the edition, alongside the content. That is, the intellectual value of a digital workstation edition is expressed not only through its textual data (primary and secondary), but also through its organizations (plural because there can be multiple coexistent organizational structures in a digital edition, none of which is necessarily subordinate to any other) and the affordances (that is, the modes of interaction with the edition and the invitations to participate in that interaction). For example, reader may page through a print edition to find a remembered line, but that is often an awkward and inexact process. A digital edition that establishes finding specific text as a goal, on the other hand, may support searching, and not just browsing, and the searching can be literal (find the exact text) or looser (e.g., find all inflected forms of a particular lexeme at once, as a single query). Beyond words, a digital edition may also incorporate the graphic visualizations of textual information, and link between the graphics and the text. Through user-oriented design and the tight integration of features, a digital workstation can make research easier and faster.

Simply put, a simple digital edition, like a traditional paper edition, presents information in a way that is controlled fully by the author or developer. A digital workstation, though, instantiates a _reader-oriented theory of edition_, and it is designed to serve as an environment for conducting research, and not only for reading the results of someone else’s research.

### Features

The features that go into a digital workstation vary according to the specific text, the type of text, and the research questions the edition anticipates and supports. itself. Here are some examples:

* Manuscripts and other unique texts, which are often physically inaccessible to users, may benefit from a digital recreation of a physical object. Example of this type of workstation include the [Blake archive](http://www.blakearchive.org/) and the [Rossetti archive](http://www.rossettiarchive.org/). Such workstations may incorporate zoom, comparison, annotation, and light-box-like features, which enrich the user’s interaction with the physical text-bearing object.
* Disciplines with well-known or well-developed reference resources my benefit from integrating access to the reference library tightly with specific moments of the text. An example of this is the [Perseus digital library](http://www.perseus.tufts.edu/hopper/text?doc=Perseus%3atext%3a2008.01.0590). 
* The preceding features may be combined, as in the prototype described at [Paul the not-so-simple](http://paul.obdurodon.org/ohrid/) (published at _Scripta &amp; e-Scripta_ 6(2008): 23–45).
* Digital workstations may also emphasize metadata, or contextual information about the text, without providing full text. Examples of this is the [Repertorium of Old Bulgarian literature and letters](http://repertorium.obdurodon.org/) and [Daniel the prisoner: A virtual florilegium](http://zatochnik.obdurodon.org/).

### Design

Designing the interface challenges scholar-developers to anticipate research needs for themselves and others. The digital workstation is not just a text, and not just a text with supporting materials; what makes it a workstation is the tight integration of its components. The developer of a digital workstation considers, on every page, where users will want to go, and builds in easy and natural access to those destinations. A user who is conducting complex research, and not just looking up isolated facts, expects to learn something at each stage, where the learning will both answer questions and engender follow-up qestions. The developer of a digital workstation needs to anticipate those follow-up questions, so that the user can reach any likely next views as easily as possible. One rule of thumb is that if the main modes of interaction are continuous browsing (e.g., turning pages in a manuscript) or dead-end queries (e.g., look something up, then hit the Back or Home button to look up something else), it probably isn’t a digital workstation. In a digital workstatioin, each view is integrated with the views that the user is likely to want to see next—which is, obviously, a challenge for the developer when one considers the diversity of users. 

### Bibliography

Birnbaum, David J., Erin Alpert, Hillary Brevig, Drew Chapman, Alyssa DeBlasio, Julie Draskoczy, Yelena Forrester, Olga Klimova, Michelle Kuhn, Raffaele Ruggiero, Oscar Swan, and Elise Thorsen . “Paul the not-so-simple.” _Scripta &amp; e-Scripta_ 6(2008): 23–45). Preprint available at <http://paul.obdurodon.org/ohrid/>.

Sels, Lara and David J. Birnbaum. “Editing the _Bdinski sbornik_ as a multilayered reality.” _Агиославика. Проблеми и подходи в изследването на Станиславовия чети-миней: доклади от едноименната конференция - 21 май 2013 г._ (_Hagioslavica. Issues and
approaches in the study of the_ Stanislav Reading Menaion: _presentations from the
conference of May 21, 2013._), ed. Diana Atanasova. Sofia: Kliment Oxridski University,
2015 (appeared in May 2016), 184–99. <https://github.com/Pittsburgh-NEH-Institute/Institute-Materials-2017/blob/master/general/2014-01-14_bdinski-sofia-paper.pdf>

----

Authors: David J. Birnbaum and Gabi Keane  
Last revised: 2018-05-04  
This work is licensed under a [Creative Commons Attribution 4.0 International License. ![](https://i.creativecommons.org/l/by/4.0/80x15.png)](http://creativecommons.org/licenses/by/4.0/)


